## Examples

### Music Player 
[Code](https://github.com/Gomez0015/betterTUI/tree/master/examples/musicPlayer)

![Demo_Screenshot](https://github.com/Gomez0015/betterTUI/blob/f7c04ba5d005b92d3084f69dbf703e725abc2346/examples/musicPlayer/image.png)

# betterTUI - collection of curses widgets for building TUI's

The purpose of betterTUI is to make creating TUI's in python with navigation, input
and colors easy and fast. I developped this library over curses because I could not find any others
which accomplished this goal. If you want to contribute to the library, you are welcome to add
Issues/PullRequests and I will look at them ASAP!

You can find the documentation here: [Documentation](https://bettertui.readthedocs.io/en/latest/)
